function doall=modified_rayleigh
clear all; close all;
% Eli Tziperman:  Solve Rayleigh equation with an additional term
% (alpha) which creates an assumetric saw-tooth:
% \ddot{x}+mu*(1-\alpha\dot{x}-\dot{x}^2)\dot{x}+x=0
% http://www.iro.umontreal.ca/~eckdoug/vibe/Relaxation/Rayleigh.html

% define parameters:
% ------------------
mu=0.03;
omega2=(2*pi/100)^2;
alpha=4.0;
% Initial values:
x(1:2,1)=[0.1,0.1]';
% time step: needs to be small enough for a given problem:
delta_t=0.02;
% Integration time:
T=1500.0;

% Number of steps:
N=abs(floor(T/delta_t));

% Integrate:
for n=1:1:N
    xp=x(:,n)';
    x_tilde=xp+delta_t*rhs(xp,mu,alpha,omega2);
    xp=xp+0.5*( rhs(xp,mu,alpha,omega2) + rhs(x_tilde,mu,alpha,omega2) )*delta_t;
    x(:,n+1)=xp';
    time(n)=n*delta_t;
end

% Plot simple time series:
axes('position',[0.1 0.6 0.8 0.35]); %RECT = [left, bottom, width, height]
plot(time(1:n),x(1,1:n));%,'+')
xlabel('time')
ylabel('x')
axes('position',[0.3 0.1 0.4 0.4]); %RECT = [left, bottom, width, height]
plot(x(1,1:50:n),x(2,1:50:n),'+')
xlabel('x')
ylabel('dx/dt')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function ff=rhs(x,mu,alpha,omega2)
% return the rhs of the dynamical system:

ff(1)=x(2);
ff(2)=mu*(1-alpha*x(2)-x(2)^2)*x(2)-omega2*x(1);
